This dataset, winetable_tb, is a contingency table containing data from a sensory evaluation of wine. The table consists of 8 rows and 5 columns representing the categories involved in the sensory evaluation.
Usage
data(winetable_tb)This dataset, winetable_tb, is a contingency table containing data from a sensory evaluation of wine. The table consists of 8 rows and 5 columns representing the categories involved in the sensory evaluation.
data(winetable_tb)